@@ -793,12 +793,12 @@ class TerraformGenerator(TemplateGenerator):
         template = {
             'resource': {},
             'terraform': {
-                'required_version': '> 0.11.0, < 0.15.0'
+                'required_version': '> 0.11.0, < 1.1.0'
             },
             'provider': {
                 'template': {'version': '~> 2'},
                 'aws': {'version': '>= 2, < 4'},
-                'null': {'version': '~> 2'},
+                'null': {'version': '>= 2, < 4'},
             },
             'data': {
                 'aws_caller_identity': {'chalice': {}},
@@ -897,6 +897,7 @@ class TerraformGenerator(TemplateGenerator):
             'action': 'lambda:InvokeFunction',
             'function_name': self._fref(resource.lambda_function),
             'principal': self._options.service_principal('s3'),
+            'source_account': '${data.aws_caller_identity.chalice.account_id}',
             'source_arn': ('arn:${data.aws_partition.chalice.partition}:'
                            's3:::%s' % resource.bucket)
         }
